@@ -7,7 +7,6 @@ import os
 import inspect
 import warnings
 import ctypes
-from contextlib import nullcontext
 from collections import defaultdict
 from . import irtools
 from .errors import UnsupportedError
@@ -15,11 +14,6 @@ from .typesystem import Type, get_signature
 from .thrift import Server, Dispatcher, dispatchermethod, Data, Client
 from .utils import get_local_ip, UNSPECIFIED
 from .targetinfo import TargetInfo
-from .rbclib import tracing_allocator
-# XXX WIP: the OmnisciCompilerPipeline is no longer omnisci-specific because
-# we support Arrays even without omnisci, so it must be renamed and moved
-# somewhere elsef
-from .omnisci_backend import OmnisciCompilerPipeline
 
 
 def isfunctionlike(obj):
@@ -347,6 +341,9 @@ class Caller:
     def describe(self):
         """Return LLVM IRs of all target devices.
         """
+        # To-Do: Move the pipeline to outside heavydb_backend
+        from rbc.heavydb.pipeline import HeavyDBCompilerPipeline
+
         lst = ['']
         fid = 0
         for device, target_info in self.remotejit.targets.items():
@@ -361,7 +358,7 @@ class Caller:
                     llvm_module, succesful_fids = irtools.compile_to_LLVM(
                         [(self.func, signatures_map)],
                         target_info,
-                        pipeline_class=OmnisciCompilerPipeline,
+                        pipeline_class=HeavyDBCompilerPipeline,
                         debug=self.remotejit.debug)
                     lst.append(str(llvm_module))
         lst.append(f'{"":-^80}')
@@ -541,7 +538,7 @@ class RemoteJIT:
     default_remote_call_hold = False
 
     def __init__(self, host='localhost', port=11532,
-                 local=False, debug=False, use_tracing_allocator=False):
+                 local=False, debug=False):
         """Construct remote JIT function decorator.
 
         The decorator is re-usable for different functions.
@@ -556,17 +553,14 @@ class RemoteJIT:
           When True, use local client. Useful for debugging.
         debug : bool
           When True, output debug messages.
-        use_tracing_allocator : bool
-          When True, enable the automatic detection of memory leaks.
         """
         if host == 'localhost':
             host = get_local_ip()
 
-        if use_tracing_allocator and not local:
-            raise ValueError('use_tracing_allocator=True can be used only with local=True')
-
-        self.debug = debug
-        self.use_tracing_allocator = use_tracing_allocator
+        if int(os.environ.get('RBC_DEBUG', False)):
+            self.debug = True
+        else:
+            self.debug = debug
         self.host = host
         self.port = int(port)
         self.server_process = None
@@ -578,11 +572,13 @@ class RemoteJIT:
         self._targets = None
 
         if local:
-            self._client = LocalClient(debug=debug,
-                                       use_tracing_allocator=use_tracing_allocator)
+            self._client = LocalClient(debug=debug)
         else:
             self._client = None
 
+    def __repr__(self):
+        return f'{type(self).__name__}(host={self.host!r}, port={self.port})'
+
     @property
     def local(self):
         localjit = type(self)(local=True, debug=self.debug)
@@ -814,13 +810,16 @@ class RemoteJIT:
         Return the corresponding LLVM IR module instance which may be
         useful for debugging.
         """
+        # To-Do: Move the pipeline to outside heavydb_backend
+        from rbc.heavydb import HeavyDBCompilerPipeline
+
         if self.debug:
             print(f'remote_compile({func}, {ftype})')
         with target_info:
             llvm_module, succesful_fids = irtools.compile_to_LLVM(
                 [(func, {0: ftype})],
                 target_info,
-                pipeline_class=OmnisciCompilerPipeline,
+                pipeline_class=HeavyDBCompilerPipeline,
                 debug=self.debug)
         ir = str(llvm_module)
         mangled_signatures = ';'.join([s.mangle() for s in [ftype]])
@@ -931,9 +930,8 @@ class DispatcherRJIT(Dispatcher):
     """Implements remotejit service methods.
     """
 
-    def __init__(self, server, debug=False, use_tracing_allocator=False):
+    def __init__(self, server, debug=False):
         super().__init__(server, debug=debug)
-        self.use_tracing_allocator = use_tracing_allocator
         self.compiled_functions = dict()
         self.engines = dict()
         self.python_globals = dict()
@@ -948,11 +946,7 @@ class DispatcherRJIT(Dispatcher):
         info : dict
           Map of target devices and their properties.
         """
-        if self.use_tracing_allocator:
-            target_info = TargetInfo.host(name='host_cpu_tracing_allocator',
-                                          use_tracing_allocator=True)
-        else:
-            target_info = TargetInfo.host()
+        target_info = TargetInfo.host()
         target_info.set('has_numba', True)
         target_info.set('has_cpython', True)
         return dict(cpu=target_info.tojson())
@@ -1002,16 +996,6 @@ class DispatcherRJIT(Dispatcher):
         arguments : tuple
           Specify the arguments to the function.
         """
-        # if we are using a tracing allocator, automatically detect memory leaks
-        # at each call.
-        if self.use_tracing_allocator:
-            leak_detector = tracing_allocator.new_leak_detector()
-        else:
-            leak_detector = nullcontext()
-        with leak_detector:
-            return self._do_call(fullname, arguments)
-
-    def _do_call(self, fullname, arguments):
         if self.debug:
             print(f'call({fullname}, {arguments})')
         ef = self.compiled_functions.get(fullname)
@@ -1076,9 +1060,8 @@ class LocalClient:
     All calls will be made in a local process. Useful for debbuging.
     """
 
-    def __init__(self, debug=False, use_tracing_allocator=False):
-        self.dispatcher = DispatcherRJIT(None, debug=debug,
-                                         use_tracing_allocator=use_tracing_allocator)
+    def __init__(self, debug=False):
+        self.dispatcher = DispatcherRJIT(None, debug=debug)
 
     def __call__(self, **services):
         results = {}
